[−][src]Crate langis
A signal is a structure that can yield an infinite amount of data. The API is very
similar to std::iter::Iterator but with the assumption that it will never end.
Modules
| comp | This module contains signals that are created using functions in the main signal trait. |
| gen | This module contains signal generators. |
| noise | Signals that deal with randomness. |
Traits
| Signal | The main signal trait. Every signal must implement this trait. |
Functions
| constant | Creates a signal that yields a constant given value. |
| cycle | Creates a signal that endlessly repeats the items of an iterator. |
| default | Creates a signal that yields the default value of |
| gen | Creates a signal that yields the return values of a given function. |
| successors | Creates a signal where each successive value is computed based on the preceding one. |